package com.ruoyi.web.v2.v1.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.uuid.UUID;
import com.ruoyi.web.v2.v1.entity.JsCheckDevice;
import com.ruoyi.web.v2.v1.entity.JsWorkshop;
import com.ruoyi.web.v2.v1.mapper.JsCheckDeviceMapper;
import com.ruoyi.web.v2.v1.service.IJsCheckDeviceService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.web.v2.v1.utils.PhoneNumberValidator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

import static com.ruoyi.common.core.domain.AjaxResult.error;
import static com.ruoyi.common.core.domain.AjaxResult.success;

/**
 * <p>
 * v2.0设备档案管理 服务实现类
 * </p>
 *
 * @author author
 * @since 2025-05-21
 */
@Service
public class JsCheckDeviceServiceImpl extends ServiceImpl<JsCheckDeviceMapper, JsCheckDevice> implements IJsCheckDeviceService {

    @Autowired
    private JsCheckDeviceMapper checkDeviceMapper;

    @Override
    public AjaxResult add(JsCheckDevice checkDevice) {
        String deviceName = checkDevice.getDeviceName();
        if (ObjectUtil.isNotEmpty(checkDevice.getPhone())) {
            if (!PhoneNumberValidator.isValidPhoneNumber(checkDevice.getPhone())) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return error("手机号码格式不正确！");
            }
        }
        Integer count = checkDeviceMapper.selectCount(new QueryWrapper<JsCheckDevice>().eq("device_name", deviceName)
                .or().eq("device_num",checkDevice.getDeviceNum()));
        if (count != 0) {
            return error("设备档案已存在！");
        } else {
            checkDeviceMapper.insert(checkDevice);
        }
        return success("添加成功");
    }

    @Override
    public AjaxResult edit(JsCheckDevice checkDevice) {
        String deviceName = checkDevice.getDeviceName();
        if (ObjectUtil.isNotEmpty(checkDevice.getPhone())) {
            if (!PhoneNumberValidator.isValidPhoneNumber(checkDevice.getPhone())) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return error("手机号码格式不正确！");
            }
        }
        Integer count = checkDeviceMapper.selectCount(new QueryWrapper<JsCheckDevice>().ne("id",checkDevice.getId()).eq("device_name", deviceName));
        if (count != 0) {
            return error("设备档案名称已存在！");
        }
        Integer count1 = checkDeviceMapper.selectCount(new QueryWrapper<JsCheckDevice>().ne("id",checkDevice.getId()).eq("device_num", checkDevice.getDeviceNum()));
        if (count1 != 0) {
            return error("设备档案编号已存在！");
        }
        checkDeviceMapper.updateById(checkDevice);
        return success("修改成功");
    }

    @Override
    public AjaxResult delete(String ids) {
        String[] split = ids.split(",");
        for (String s : split) {
            checkDeviceMapper.deleteById(s);
        }

        return success("删除成功");
    }

    @Override
    public AjaxResult page(Integer pageNum, Integer pageSize, String deviceNum, String deviceName) {
        QueryWrapper<JsCheckDevice> queryWrapper = new QueryWrapper<>();
        Page<JsCheckDevice> page = new Page<>(pageNum, pageSize);
        queryWrapper.like(StringUtils.isNotEmpty(deviceNum), "device_num", deviceNum).or()
                .like(StringUtils.isNotEmpty(deviceName), "device_name", deviceName);
        return success(checkDeviceMapper.selectPage(page, queryWrapper));
    }

    @Override
    public AjaxResult listAll() {
        return success(checkDeviceMapper.selectList(null));
    }
}
