package com.ruoyi.app.mapper;

import java.util.List;

import com.ruoyi.app.DTO.SlaughterRelationDTO;
import com.ruoyi.app.domain.Pigpen;
import com.ruoyi.app.domain.SlaughterRelation;
import com.ruoyi.app.domain.request.ExportSlaughterRelation;
import com.ruoyi.app.domain.request.ReqGetSlaughterRelation;
import com.ruoyi.app.domain.request.ReqSlaughterRelation;
import com.ruoyi.app.domain.response.RespGetSlaughterRelation;

/**
 * 血码关系Mapper接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface SlaughterRelationMapper 
{
    /**
     * 查询血码关系
     * 
     * @param id 血码关系主键
     * @return 血码关系
     */
    public SlaughterRelation selectSlaughterRelationById(Long id);

    /**
     * 查询血码关系列表
     * 
     * @param req 血码关系
     * @return 血码关系集合
     */
    public List<SlaughterRelation> selectSlaughterRelationList(ReqSlaughterRelation req);

    /**
     * 导出血码关系列表
     *
     * @return 血码关系集合
     */
    public List<SlaughterRelationDTO> exportSlaughterRelationList(ExportSlaughterRelation req);

    /**
     * 查询供应商血码数量列表
     *
     * @param req 查询条件
     * @return 供应商血码数量关系集合
     */
    public List<RespGetSlaughterRelation> selectSupplierList(ReqGetSlaughterRelation req);

    /**
     * 校验血码是否唯一
     *
     * @param slaughterCode 血码
     * @return 结果
     */
    public SlaughterRelation checkCodeUnique(String slaughterCode);

    /**
     * 校验供应商的肉商是否唯一
     *
     * @param slaughterRelation 血码关系
     * @return 结果
     */
    public SlaughterRelation checkPurchaserUnique(SlaughterRelation slaughterRelation);

    /**
     * 新增血码关系
     * 
     * @param slaughterRelation 血码关系
     * @return 结果
     */
    public int insertSlaughterRelation(SlaughterRelation slaughterRelation);

    /**
     * 批量新增血码关系
     *
     * @param list 血码关系
     * @return 结果
     */
    public int insertSlaughterRelationBatch(List<SlaughterRelation> list);

    /**
     * 修改血码关系
     * 
     * @param slaughterRelation 血码关系
     * @return 结果
     */
    public int updateSlaughterRelation(SlaughterRelation slaughterRelation);

    /**
     * 删除血码关系
     * 
     * @param id 血码关系主键
     * @return 结果
     */
    public int deleteSlaughterRelationById(Long id);

    /**
     * 批量删除血码关系
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSlaughterRelationByIds(Long[] ids);

    /**
     * 根据供应商ID统计血码数量
     *
     * @param supplierId 供应商ID
     * @return 结果
     */
    public int countSlaughterRelationBySupplier(Long supplierId);

    /**
     * 根据肉商ID统计血码数量
     *
     * @param purchaserId 肉商ID
     * @return 结果
     */
    public int countSlaughterRelationByPurchaser(Long purchaserId);
}
