package com.ruoyi.app.mapper;

import java.util.List;
import com.ruoyi.app.domain.Staff;
import com.ruoyi.app.domain.StaffPost;
import com.ruoyi.system.domain.SysUserRole;

/**
 * 人员Mapper接口
 * 
 * @author coede
 * @date 2025-03-20
 */
public interface StaffMapper 
{
    /**
     * 查询人员
     * 
     * @param id 人员主键
     * @return 人员
     */
    public Staff selectStaffById(Long id);

    /**
     * 查询人员列表
     * 
     * @param staff 人员
     * @return 人员集合
     */
    public List<Staff> selectStaffList(Staff staff);

    /**
     * 新增人员
     * 
     * @param staff 人员
     * @return 结果
     */
    public int insertStaff(Staff staff);

    /**
     * 修改人员
     * 
     * @param staff 人员
     * @return 结果
     */
    public int updateStaff(Staff staff);

    /**
     * 删除人员
     * 
     * @param id 人员主键
     * @return 结果
     */
    public int deleteStaffById(Long id);

    /**
     * 批量删除人员
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteStaffByIds(Long[] ids);

    /**
     * 根据岗位ID获取人员数量
     *
     * @param postId 岗位ID
     * @return 结果
     */
    public int countStaffByPostId(Long postId);

    /**
     * 批量新增人员岗位信息
     *
     * @param staffPostList 人员岗位列表
     * @return 结果
     */
    public int batchStaffPost(List<StaffPost> staffPostList);

    /**
     * 通过人员ID删除人员和岗位关联
     *
     * @param staffId 人员ID
     * @return 结果
     */
    public int deleteStaffPostByStaffId(Long staffId);
}
