package com.ruoyi.app.service;

import java.util.List;

import com.ruoyi.app.DTO.ValidDistributeListDTO;
import com.ruoyi.app.DTO.ValidSlaughterCodeDTO;
import com.ruoyi.app.domain.DistributeBatch;
import com.ruoyi.app.domain.HarmlessTreatment;

/**
 * 分销批次Service接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface IDistributeBatchService 
{
    /**
     * 查询分销批次
     * 
     * @param id 分销批次主键
     * @return 分销批次
     */
    public DistributeBatch selectDistributeBatchById(Long id);

    /**
     * 查询分销批次列表
     * 
     * @param distributeBatch 分销批次
     * @return 分销批次集合
     */
    public List<DistributeBatch> selectDistributeBatchList(DistributeBatch distributeBatch);

    /**
     * 校验分销批次的肉商是否唯一
     *
     * @param  distributeBatch 分销批次
     * @return 结果
     */
    public DistributeBatch checkPurchaserUnique(DistributeBatch distributeBatch);

    /**
     * 校验数量是否超出了准宰数量
     *
     * @param distributeBatch 分销批次
     * @return 结果
     */
    public boolean checkTotalLessThanAmount(DistributeBatch distributeBatch);

    /**
     * 获取血码关联的未完成屠宰的分销批次
     *
     * @param distributeBatch 分销批次
     * @return 结果
     */
    public List<ValidDistributeListDTO> selectValidDistribute(DistributeBatch distributeBatch);

    /**
     * 新增分销批次
     * 
     * @param distributeBatch 分销批次
     * @return 结果
     */
    public int insertDistributeBatch(DistributeBatch distributeBatch);

    /**
     * 批量新增分销批次
     *
     * @param list 分销批次
     * @return 结果
     */
    public int insertDistributeBatchByBatch(List<DistributeBatch> list);

    /**
     * 修改分销批次
     * 
     * @param distributeBatch 分销批次
     * @return 结果
     */
    public int updateDistributeBatch(DistributeBatch distributeBatch);

    /**
     * 批量删除分销批次
     * 
     * @param ids 需要删除的分销批次主键集合
     * @return 结果
     */
    public int deleteDistributeBatchByIds(Long[] ids);

    /**
     * 获取屠宰数量分布情况
     *
     * @param id 分销批次主键
     * @return 结果
     */
    public int deleteDistributeBatchById(Long id);

    /**
     * 获取存在未完成（24小时内）的分销批次的血码
     *
     * @return 结果
     */
    public List<ValidSlaughterCodeDTO> selectValidCode();
}
