package com.ruoyi.app.service.impl;

import java.util.List;

import com.ruoyi.app.DTO.RegionTreeDTO;
import com.ruoyi.app.domain.Pigpen;
import com.ruoyi.app.mapper.MonitorMapper;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.app.mapper.RegionMapper;
import com.ruoyi.app.domain.Region;
import com.ruoyi.app.service.IRegionService;

/**
 * 区域Service业务层处理
 * 
 * @author coede
 * @date 2025-03-19
 */
@Service
public class RegionServiceImpl implements IRegionService 
{
    @Autowired
    private RegionMapper regionMapper;

    @Autowired
    private MonitorMapper monitorMapper;

    /**
     * 查询区域
     * 
     * @param id 区域主键
     * @return 区域
     */
    @Override
    public Region selectRegionById(Long id)
    {
        return regionMapper.selectRegionById(id);
    }

    /**
     * 查询区域列表
     * 
     * @param region 区域
     * @return 区域
     */
    @Override
    public List<Region> selectRegionList(Region region)
    {
        return regionMapper.selectRegionList(region);
    }

    /**
     * 查询区域设备树列表
     *
     * @param region 区域
     * @return 区域集合
     */
    public List<RegionTreeDTO> selectRegionTreeList(Region region)
    {
        return regionMapper.selectRegionTreeList(region);
    }

    /**
     * 校验待区域名称是否唯一
     *
     * @param region 区域
     * @return 结果
     */
    @Override
    public boolean checkRegionNameUnique(Region region)
    {
        Long regionId = StringUtils.isNull(region.getId()) ? -1L : region.getId();
        Region info = regionMapper.checkRegionNameUnique(region.getRegionName());
        if (StringUtils.isNotNull(info) && info.getId().longValue() != regionId.longValue())
        {
            return false;
        }
        return true;
    }

    /**
     * 新增区域
     * 
     * @param region 区域
     * @return 结果
     */
    @Override
    public int insertRegion(Region region)
    {
        region.setCreateTime(DateUtils.getNowDate());
        return regionMapper.insertRegion(region);
    }

    /**
     * 修改区域
     * 
     * @param region 区域
     * @return 结果
     */
    @Override
    public int updateRegion(Region region)
    {
        region.setUpdateTime(DateUtils.getNowDate());
        return regionMapper.updateRegion(region);
    }

    /**
     * 批量删除区域
     * 
     * @param ids 需要删除的区域主键
     * @return 结果
     */
    @Override
    public int deleteRegionByIds(Long[] ids)
    {
        for (Long id : ids)
        {
            if(id !=null){
                if (monitorMapper.countMonitorByRegion(id) > 0)
                {
                    throw new ServiceException("有关联设备，不能删除");
                }

            }
        }
        return regionMapper.deleteRegionByIds(ids);
    }

    /**
     * 删除区域信息
     * 
     * @param id 区域主键
     * @return 结果
     */
    @Override
    public int deleteRegionById(Long id)
    {
        if(id !=null){
            if (monitorMapper.countMonitorByRegion(id) > 0)
            {
                throw new ServiceException("有关联设备，不能删除");
            }
        }
        return regionMapper.deleteRegionById(id);
    }
}
